--[[
	80x80
	(其中边框80x80，道具图片由100x100压缩到68x68)	
]]
ItemNode = class("ItemNode", function(params)
    local info = zc._getIconInfo(params)
    local obj = zc.createSprite(info.bgImg)
    obj._info = info
    return ZCTouchExtend.extend(obj)
end)

function ItemNode:ctor(params)
    self.params = params
    self._showDetailPop = params.showDetailPop
    self._touchCallBack = params.listener
    self._swallowTouched = params.swallowTouched
    
    self:setPosition(params.pos or cc.p(0, 0))
    self:setName(params.name or "icon")
    self:setScale(params.scale or 1)

    -- 图片资源信息
    local info = self._info
    -- dump(info, "wm-----info")

    local pic = zc.createSprite()
    pic:setName("pic")
    -- pic:setPosition(cc.pMul(cc.pFromSize(self:getContentSize()), 0.5))
    pic:setPosition(cc.p(self:getContentSize().width*0.5,self:getContentSize().height*0.5+(info["justY"] or 0)))
    self:addChild(pic)

    if info.mainType == zc.mainTypeSoldierCard then --武将卡由于图片原因必须用ClippingNode来切
        local clippNode = cc.ClippingNode:create()
        clippNode:setInverted(false)
        clippNode:setAlphaThreshold(0.5)
        pic:addChild(clippNode)
        clippNode:setName("clippNode")
        local template = zc.createSprite(info.bgImg)--模板
        template:setScale(110/120)
        clippNode:setStencil(template)
        clippNode._template = template
        local content = zc.createSprite(info.img)--底板
        content:setScale(info.scale)
        clippNode:addChild(content)
        content:setName("content")
        clippNode._content = content
    else
        pic:setScale(info.scale)
        if zc.checkFileExist(info.bigImg) then
            pic:setTexture(info.bigImg)
        else
            pic:setTexture(info.img)
        end
    end

    if zc.checkFileExist(info.bigImg) then
        pic:setTexture(info.bigImg)
    end

    -- 外框
    self:doBorderImg()
    --0 英雄的location 
    self:doLocationImg()
    --1 碎片
    self:doFragmentImg()
    --1 锁定
    self:doLockImg()
    --2 等级Label (右下方)
    self:doLevelLabel(params)
    --2 数目Label (右下方)
    self:doCountLabel(params)
    --0 属性Label 
    self:doAttrLabel(params)
    --0 名称Lable
    self:doNameLabel(params)
    --0 双倍Lable
    self:doBeiLabel(params)
    -- 处理置灰
    self:doShowGray(params)
    -- 是否播放动作
    if params.delayTime then
        self:setScale(0.2)
        self:setVisible(false)
        self:runAction(cc.Sequence:create(
            cc.DelayTime:create(params.delayTime),
            cc.Show:create(),
            cc.EaseElasticOut:create(cc.ScaleTo:create(0.1, params.scale or 1))
        ))
    end
    self:setTouchShowTip()
end

function ItemNode:updatByData( params )
    self.params = params
    self._showDetailPop = params.showDetailPop
    self._touchCallBack = params.listener
    self._swallowTouched = params.swallowTouched
    local info = zc._getIconInfo(params)
    -- dump(info, "wm-----info")
    self._info = info
    self._showDetailPop = params.showDetailPop

    self:setTexture(info.bgImg)
    -- 变更头像图片
    local pic = self:getChildByName("pic")
    local clippNode = pic:getChildByName("clippNode")

    if info.mainType == zc.mainTypeSoldierCard then --武将卡由于图片原因必须用ClippingNode来切
        pic:setScale(1.0)
        pic:init()
        if not clippNode then
            clippNode = cc.ClippingNode:create()
            clippNode:setInverted(false)
            clippNode:setAlphaThreshold(0.5)
            pic:addChild(clippNode)
            clippNode:setName("clippNode")
        end
        local template = clippNode._template
        if tolua.isnull(template) then
            template = zc.createSprite(info.bgImg)--模板
            template:setScale(110/120)
            clippNode:setStencil(template)
            clippNode._template = template
        else
            template:setTexture(info.bgImg)
            template:setScale(110/120)
        end

        local content = clippNode:getChildByName("content")
        if not content then
            content = zc.createSprite(info.img)--底板
            content:setScale(info.scale)
            clippNode:addChild(content)
            content:setName("content")
        else
            content:setScale(info.scale)
            content:setTexture(info.img)
        end
    else
        if clippNode then
            clippNode:removeFromParent()
        end
        pic:setScale(info.scale)
        if zc.checkFileExist(info.bigImg) then
            pic:setTexture(info.bigImg)
        else
            pic:setTexture(info.img)
            -- pic:loadTexture(info.img, string.find(info.img,"/") and 0 or 1)
        end
    end
    
    if params.pos then
        self:setPosition(params.pos)
    end
    if params.name then
        self:setName(params.name)
    end
    if params.scale then
        self:setScale(params.scale)
    end

    self:doBorderImg()
    self:doLocationImg()
    self:doFragmentImg()
    self:doLockImg()
    self:doLevelLabel(params)
    self:doCountLabel(params)
    self:doAttrLabel(params)
    self:doNameLabel(params)
    self:doBeiLabel(params)
    self:doShowGray(params)
    self:setTouchShowTip()
    return info
end

--------------------touch--------------------

function ItemNode:addTouch()
    if self._listener then
        return
    end
    --开始注册点击事件
    local listener = cc.EventListenerTouchOneByOne:create()
    
    self._disPos = cc.p(0, 0)
    listener:registerScriptHandler(function(touch, event) 
        self._disPos.x= 0
        self._disPos.y = 0
        self.isMoveOrEnd = false
        local isVisible = self:isAllParentsVisible(self)
        local isContain = self:isContainTouch(self,touch)
        if isVisible and isContain then
            if self._showDetailPop then
                local function scriptHandler( tag )
                    if tag == "cleanup" then
                        if zc.getPop("itemDetail")  then 
                            zc.closePop("itemDetail")
                            self._notEndcallback = nil
                        end 
                    end
                end
                self:registerScriptHandler(scriptHandler)
                self._action = cc.Sequence:create(
                    cc.DelayTime:create(0.3),
                    cc.CallFunc:create(function ()
                        if self.isMoveOrEnd == false then
                            self:showTip()
                        end
                    end))
                self:runAction(self._action)
            end
            return true
        end
        return false
    end, cc.Handler.EVENT_TOUCH_BEGAN)

    listener:registerScriptHandler(function(touch, event)
        local touchLocation = touch:getLocation() --yanyuling
        local prevLocation = touch:getPreviousLocation() --yanyuling
        self._disPos.x = self._disPos.x + math.abs(cc.pSub(touchLocation, prevLocation).x) --yanyuling
        self._disPos.y = self._disPos.y + math.abs(cc.pSub(touchLocation, prevLocation).y) --yanyuling
        if self._disPos.x > 15 or self._disPos.y > 15 then
            self.isMoveOrEnd = true
        end
    end, cc.Handler.EVENT_TOUCH_MOVED)

    local callback = function(touch, event)
        if self._action then
            self:stopAction(self._action)
        end
        if self._showDetailPop then
            self:unregisterScriptHandler()
            if zc.getPop("itemDetail") then 
                zc.closePop("itemDetail")
                if self._notEndcallback then
                    self._notEndcallback = nil
                    return
                end
            end
        end
        if self.isMoveOrEnd then
            self.isMoveOrEnd = false
            return
        end
        local isVisible = self:isAllParentsVisible(self);
        local isContain = self:isContainTouch(self,touch);
        if isVisible and isContain then
            if self._touchCallBack then
                self._touchCallBack()
            end
        end
    end
    listener:registerScriptHandler(callback, cc.Handler.EVENT_TOUCH_ENDED)
    listener:registerScriptHandler(callback, cc.Handler.EVENT_TOUCH_CANCELLED)
    local eventDispatcher = cc.Director:getInstance():getEventDispatcher()
    --给精灵添加点击事件
    eventDispatcher:addEventListenerWithSceneGraphPriority(listener, self)
    self._listener = listener
    local _swallow = self._swallowTouched == nil and false or self._swallowTouched
    self._swallowTouched = nil
    self:setSwallowTouches(_swallow)
end

function ItemNode:setSwallowTouches( swallow )
    if self._swallowTouched == swallow then
        return
    end
    self._swallowTouched = swallow
    if self._listener then
        if self._swallowTouched == true then
            self._listener:setSwallowTouches(true)
        else
            self._listener:setSwallowTouches(false)
        end
    end
end

function ItemNode:setTouchEnabled( touchEnabled )
    if self._touchFlag == touchEnabled then
        return
    end
    self._touchFlag = touchEnabled
    if self._touchFlag == true then
        self:addTouch()  
    else
        if self._listener then
            local eventDispatcher = cc.Director:getInstance():getEventDispatcher()
            eventDispatcher:removeEventListener(self._listener)
            self._listener = nil
        end
    end
end

function ItemNode:setTouchEndedShowTip( swallowTouch )
    self:setTouchEndedCall(function()
        self:showTip()
    end, swallowTouch)
end

function ItemNode:setTouchEndedCall( func, swallowTouch )
    self._touchCallBack = func
    self._swallowTouched = swallowTouch
    self:setTouchShowTip()
end

function ItemNode:setTouchShowTip()
    local _flag = false
    if self._touchCallBack or self._showDetailPop then
        _flag = true
    end
    if self._touchFlag ~= _flag then
        self._touchFlag = nil
        self:setTouchEnabled(_flag)
    end
end

function ItemNode:showTip()
    --如果弹出了信息框，就不响应end回调
    self._notEndcallback = true
    if zc.getPop("itemDetail") then 
        return
    end
    local pos = self:convertToWorldSpace(cc.p(0, 0))

    local _runningScene = cc.Director:getInstance():getRunningScene()
    if not _runningScene then
        return
    end
    local _name = _runningScene:getName()
    local _tb = {
        pos = pos, 
        params = self.params.data, 
        primaryId = self.params.primaryId
    }
    if tonumber(_tb.params.mainType) == zc.mainTypeProp then
        local _db = gameData.getDataFromCacheWithPrimaryKey("item", _tb.params.id)
        if tonumber(_db.subType) == zc.subTypeBox then
            self:initBoxUI(_name, _tb.params.id)
            return
        end
    elseif tonumber(_tb.params.mainType) == zc.mainTypeSoldier then
        zc.createHeroInfoPop({heroId = _tb.params.id, showHero = true})
        return
    end
    if _name == LAYER_NAME_TAG.LAYER_MAINCITY then
        zc.createPop("itemDetail", _tb)
    else
        local _pop = requires("src/pop/itemDetailPop.lua"):create(_tb)
        _pop:setName("itemDetail")
        _runningScene:addChild(_pop, 1)
    end
end

function ItemNode:initBoxUI( name, id )
    local _flag = name == LAYER_NAME_TAG.LAYER_MAINCITY
    local _pop = ZCPopLayer:create({opacityValue=255*0.7, isRemoveLayout = _flag})
    if _flag then
        LayerManager.addNode(_pop, {isPop = true})
    else
        _runningScene:addChild(_pop, 1)
    end

    local _db = gameData.getDataFromCacheWithPrimaryKey("treasure", id)
    local _itemInfos = string.split(_db.items, ",")

    local popBg = zc.createSprite("res/Main/wushenTower/pop_reward.png")
    popBg:setPosition(zc.width*0.5, zc.height*0.5)
    _pop:addContent(popBg)
    local popSize = popBg:getContentSize()

    local __tmpType = tonumber(_db.type) or 0
    if __tmpType == 3 then
        local _label = zc.createLabel({
            text = LANGUAGE_ITEMNODE_USERBOX(#_itemInfos),
            fontSize = 20,
            color = cc.c3b(113, 86, 74),
            pos = cc.p(popSize.width*0.5, popSize.height - 90),
        })
        popBg:addChild(_label)
    end


    local _closeBtn = zc.createCommomBtn({
        tag = 1,
        btnText = zc.lang("close2"),
        needSwallow = false,
        anchor = cc.p(0.5, 0.5),
        pos = cc.p(popSize.width*0.5, 65),
        endCallback = function()
            _pop:hide()
        end,
    })
    popBg:addChild(_closeBtn, 1)

    local tableSize = cc.size(435, 132)
    local myTableBg = ccui.Scale9Sprite:create(cc.rect(26,25,1,1), "res/Main/wushenTower/pop_tableBg.png")
    myTableBg:setContentSize(tableSize)
    myTableBg:setPosition(popSize.width*0.5, popSize.height*0.5 + 20)
    popBg:addChild(myTableBg)

    tableSize.width = tableSize.width - 4
    tableSize.height = tableSize.height - 4
    local myTable = zc.ZCTableView:create(tableSize)
    myTable:setPosition(2, 2)
    myTable:setInertia(true) --设置惯性
    myTable:setBounceable(true)
    myTable:setDirection(zctech.SCROLLVIEW_DIRECTION_HORIZONTAL) --设置横向纵向
    myTable:setDelegate()
    myTable:setVerticalFillOrder(zctech.TABLEVIEW_FILL_TOPDOWN)
    myTableBg:addChild(myTable)
    
    local _cellW, _cellH = 110, tableSize.height 
    local function cellSizeForTable(table,idx)
        return _cellH, _cellW
    end
    local function numberOfCellsInTableView(table)
        return #_itemInfos
    end
    local function tableCellAtIndex(table,idx)
        local nowIdx = idx + 1
        local cell = table:dequeueCell()
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
        end
        cell:removeAllChildren()

        local _idx = idx + 1
        local _data = _itemInfos[_idx]
        local _info = string.split(_data, "|")
        local _icon = zc.createIconByData({
            data = {
                mainType = _info[1],
                type = _info[2],
                id = _info[2],
                num = _info[3],
            },
            pos = cc.p(_cellW*0.5, _cellH*0.5)
        })
        _icon:setTouchEndedShowTip()
        _icon:setScale(0.8)
        cell:addChild(_icon)
        return cell
    end
    myTable:registerScriptHandler(numberOfCellsInTableView,cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
    myTable:registerScriptHandler(cellSizeForTable,cc.TABLECELL_SIZE_FOR_INDEX)
    myTable:registerScriptHandler(tableCellAtIndex,cc.TABLECELL_SIZE_AT_INDEX)
    myTable:reloadData()

    _pop:show()
end


-----------------UI更新-----------------

function ItemNode:doBorderImg()
    local _info = self._info
    local _borderImg = self:getChildByName("border")
    local img = _info.borderImg
    if _borderImg then
        if img then
            _borderImg:setVisible(true)
            _borderImg:setTexture(img)
        else
            _borderImg:setVisible(false)
        end
    else
        if img then
            _borderImg = zc.createSprite(img)
            _borderImg:setName("border")
            self:addChild(_borderImg, 1)
        end
    end
end

function ItemNode:doLocationImg()
    local _info = self._info
    local img = _info.locationImg
    local _locationImg = self:getChildByName("locationImg")
    if _locationImg then
        if img then
            _locationImg:setVisible(true)
            _locationImg:setTexture(img)
        else
            _locationImg:setVisible(false)
        end
    else
        if img then
            _locationImg = zc.createSprite(img)
            _locationImg:setPosition(-40, 40)
            _locationImg:setName("locationImg")
            self:addChild(_locationImg, 10)
        end
    end
end


function ItemNode:doFragmentImg()
    local _info = self._info
    local img = _info.fragmentImg
    local _fragmentImg = self:getChildByName("fragmentImg")
    if _fragmentImg then
        if img then
            _fragmentImg:setVisible(true)
            _fragmentImg:setTexture(img)
        else
            _fragmentImg:setVisible(false)
        end
    else
        if img then
            _fragmentImg = zc.createSprite(img)
            _fragmentImg:setAnchorPoint(1, 1)
            _fragmentImg:setName("fragmentImg")
            self:addChild(_fragmentImg)
        end
    end
    if img then
        if _info.mainType == zc.mainTypeSoldierCard then --对武将卡的碎片icon调整位置 
            _fragmentImg:setPosition(self:getContentSize().width - 6, self:getContentSize().height+6)
        else
            _fragmentImg:setPosition(self:getContentSize().width - 1, self:getContentSize().height - 1)
        end
    end
    img = _info.qualificationImg
    local _qualificationImg = self:getChildByName("qualificationImg")
    if _qualificationImg then
        if img then
            _qualificationImg:setVisible(true)
            _qualificationImg:setTexture(img)
        else
            _qualificationImg:setVisible(false)
        end
    else
        if img then
            _qualificationImg = zc.createSprite(img)
            _qualificationImg:setAnchorPoint(0, 0)
            _qualificationImg:setPosition(-5, -1)
            _qualificationImg:setScale(1.2)
            _qualificationImg:setName("qualificationImg")
            self:addChild(_qualificationImg)
        end
    end
end


function ItemNode:doLockImg()
    local _info = self._info
    local _lockImg = self:getChildByName("lockImg")
    local _data = PlayerData:getHeroSoulInfoById(self.params.primaryId)
    if _info.mainType ~= zc.mainTypeHeroSoul or not _data then
        if _lockImg then
            _lockImg:setVisible(false)
        end
        return
    end
    local _status = tonumber(_data.status) or 0
    if _status == 0 then
        if _lockImg then
            _lockImg:setVisible(false)
        end
        return
    end
    if _lockImg then
        _lockImg:setVisible(true)
    else
        _lockImg = zc.createSprite("res/Main/heroSoul/iconLock.png")
        _lockImg:setPosition(self:getContentSize().width - 30, self:getContentSize().height - 30)
        _lockImg:setName("lockImg")
        self:addChild(_lockImg)
    end
end

function ItemNode:doLevelLabel( params )
    local _info = self._info
    local _levelLabel = self:getChildByName("levelLabel")
    local _reincarnateImg = self:getChildByName("reincarnateImg")
    local _level = tostring(_info.level) or ""

    if params.showLevel and _level ~= "" then
        local _reincarnate = tonumber(_info.reincarnate) or 0
        if _reincarnate > 0 then
            _level = _reincarnate .. zc.lang("turn") .. " " .. _level
        end
        if _reincarnateImg then
            if _info.reincarnateImg then
                _reincarnateImg:setVisible(true)
                _reincarnateImg:setTexture(_info.reincarnateImg)
            else
                _reincarnateImg:setVisible(false)
            end
        else
            _reincarnateImg = zc.createSprite(_info.reincarnateImg)
            _reincarnateImg:setAnchorPoint(0, 0)
            _reincarnateImg:setPosition(1, 1)
            self:addChild(_reincarnateImg, 2)
            _reincarnateImg:setName("reincarnateImg")
        end

        if _levelLabel then
            _levelLabel:setVisible(true)
            _levelLabel:setString(_level)
        else
            _levelLabel = zc.createLabel({
                text = _level,
                name = "levelLabel",
                fontSize = 22,
                ap = cc.p(0, 0),
                pos = cc.p(3, 3),
                outLine = true,
            })
            self:addChild(_levelLabel, 2)
        end
    else
        if _levelLabel then
            _levelLabel:setVisible(false)
        end
        if _reincarnateImg then
            _reincarnateImg:setVisible(false)
        end
    end

    local _gradeDi = self:getChildByName("gradeDi")
    
    local _grade = tonumber(_info.grade) or 0
    if _grade ~= 0 then
        local _gradeLabel
        if not _gradeDi then
            _gradeDi = zc.createSprite("res/Main/common/weaponCastDi.png", _size)
            _gradeDi:setAnchorPoint(1, 1)
            _gradeDi:setPosition(self:getContentSize().width - 5, self:getContentSize().height - 8)
            _gradeDi:setName("gradeDi")
            self:addChild(_gradeDi, 2)
            local _size = _gradeDi:getContentSize()
            _gradeLabel = zc.createLabel({
                name = "gradeLabel",
                fontSize = 24,
                pos = cc.p(_size.width*0.5, _size.height*0.5),
                outLine = true,
                color = cc.c3b(0, 255, 12),
            })
            _gradeDi:addChild(_gradeLabel)
        else
            _gradeLabel = _gradeDi:getChildByName("gradeLabel")
        end
        _gradeDi:setVisible(true)
        _gradeLabel:setString("+" .. _grade)
    else
        if _gradeDi then
            _gradeDi:setVisible(false)
        end
    end
end

function ItemNode:doCountLabel( params )
    local _info = self._info
    local _countLabel = self:getChildByName("countLabel")
    local _count = tonumber(_info.num) or 0
    local _flag = true

    if params.showCount then
        _flag = true
    elseif params.hideCount or _count <= 1 then
        _flag = false
    end
    _count = zc.getWan(_count)

    if _flag then
        --国家科技
        if _info.mainType == zc.mainTypeTech then
            _count = zc.getLevelTipShow() .. _count
        end
    end

    if _countLabel then
        if _flag then

            _countLabel:setVisible(true)
            _countLabel:setString(_count)
        else
            _countLabel:setVisible(false)
        end
    else
        if _flag then
            local _needStroke = params.countOutline == nil and true or params.countOutline
            _countLabel = zc.createLabel({
                text = _count,
                fontSize = 28, 
                name = "countLabel", 
                color = display.COLOR_WHITE, 
                pos = cc.p(self:getContentSize().width - 6, 0), 
                align = kCCTextAlignmentRight, 
                ap = cc.p(1, 0),
                outLine = _needStroke,
            })
            self:addChild(_countLabel, 2)
        end
    end
end

function ItemNode:doAttrLabel( params )
    local _info = self._info
    local _attrLabel = self:getChildByName("attrLabel")
    
    if params.attrLabel then
        local nowCount = tonumber(params.attrLabel.now) or 0
        local needCount = tonumber(params.attrLabel.need) or 1

        local attr1 = ""
        local attr2 = ""
        local attr3 = ""

        if _info.infoType == zc.dataTypeSilver then -- 如果是金币
            nowCount = PlayerData.resourcesInfo.silver
            attr1 = needCount
        elseif _info.infoType == zc.dataTypeSoul then
            nowCount = PlayerData.resourcesInfo.soul
            attr1 = needCount
        else
            attr1 = nowCount
            attr2 = "/"
            attr3 = needCount
        end

        local _fontColor = nowCount < needCount and display.COLOR_RED or display.COLOR_GREEN
        local _str = attr1 .. attr2 .. attr3
        if _attrLabel then
            _attrLabel:setText(_str)
            _attrLabel:setColor(_fontColor)
        else
            _attrLabel = zc.createLabel({
                text = _str,
                color = _fontColor,
                fontName = zc.getFont(2),
                outLine = true,
                name = "attrLabel",
                pos = cc.p(self:getContentSize().width - 6, 0),
                ap = cc.p(1, 0),
                fontSize = 24,
            })
            self:addChild(_attrLabel)
        end
    else
        if _attrLabel then
            _attrLabel:setVisible(false)
        end
    end
end

function ItemNode:doNameLabel( params )
    local _info = self._info
    local _nameLabel = self:getChildByName("nameLabel")
    
    if params.showName == true then
        local _fontColor = params.showGray == 1 and zc.nameColor(1) or zc.nameColor( _info.quality or _info.star)
        local _text = params.nameText or _info.name
        if _nameLabel then
            _nameLabel:setColor(_fontColor)
            _nameLabel:setText(_text)
        else
            _nameLabel = zc.createLabel({
                text = _text, 
                stroke = params.stroke, 
                name = "nameLabel", 
                color = _fontColor, 
                pos = cc.p(0, -75), 
                fontSize = 24, 
            })
            self:addChild(_nameLabel)
        end
    else
        if _nameLabel then
            _nameLabel:setVisible(false)
        end
    end 
end

function ItemNode:doBeiLabel( params ) 
    local _bei = tonumber(params.showBei) or 1
    local _beiImg = self:getChildByName("BeiImg")
    if _bei > 1 then
        if _beiImg then
            _beiImg.label:setString(_bei .. zc.lang("zi_bei"))
        else
            _beiImg = zc.createSprite("res/Main/activity/blackMarket/corner.png")
            _beiImg:setAnchorPoint(0, 1)
            _beiImg:setPosition(0, self:getContentSize().height)
            self:addChild(_beiImg, 2)
            _beiImg:setName("BeiImg")

            local _discountLab = zc.createLabel({
                text = _bei .. zc.lang("zi_bei"),
                fontSize = 22,
                outLine = true,
                color2 = cc.c3b(233, 64, 28),
                pos = cc.p(_beiImg:getContentSize().width/2 - 12, _beiImg:getContentSize().height/2 + 12),
            })  
            _discountLab:setRotation( -45 )
            _beiImg:addChild(_discountLab)
            _beiImg.label = _discountLab
        end
    else
        if _beiImg then
            _beiImg:setVisible(false)
        end
    end
end

function ItemNode:doShowGray(params)
    local _pic = self:getChildByName("pic")
    if params.showGray then
        if _pic then
            if self._info.mainType == zc.mainTypeSoldierCard then
                local clippNode = _pic:getChildByName("clippNode")
                local content = clippNode._content
                zc.setGray(content)
            else
                zc.setGray(_pic:getChildByName("content")) 
            end
            zc.setGray(_pic)
        end
        zc.setGray(self:getChildByName("fragmentImg"))
        zc.setGray(self) --边框需要置灰
    else
        if _pic then
            if self._info.mainType == zc.mainTypeSoldierCard then
                local clippNode = _pic:getChildByName("clippNode")
                local content = clippNode._content
                zc.setGray(content, false)
            else
                zc.setGray(_pic:getChildByName("content"), false)
            end
            zc.setGray(_pic, false)
        end
        zc.setGray(self:getChildByName("fragmentImg"), false)
        zc.setGray(self, false)
    end
end
--     创建默认参数
-- local defaultParams = {
-- }
function ItemNode:createWithParams(params)
    return ItemNode.new(params)
end

