--[[
	竞速活动
	唐实聪
	2016.6.3
]]
local SpeedLayer = class("SpeedLayer", function()
    local layer = cc.Sprite:create()
    layer:setContentSize( 720, 463 )
	return layer
end)

function SpeedLayer:create( params )
	return SpeedLayer.new( params )
end

function SpeedLayer:ctor( params )
    self._activityType = params.activityType
	self:initData( params )
	self:initUI()
	local function onNodeEvent(event)
        if "cleanup" == event then
            self:onCleanup()
        end
    end
    self:registerScriptHandler(onNodeEvent)
end

function SpeedLayer:onCleanup()
	if self._timer then
		scheduler.unscheduleGlobal( self._timer )
		self._timer = nil
	end
end

function SpeedLayer:initData( params )
	self:buildStatus( params.status )

	self._timeInfo = params.activeInfo or {}

	-- 奖励数据
	self._rewardList = {}
	-- 其他数据
	self._otherList = gameData.getAllDataWithNoClone( "speed" )
	for i, v in pairs( self._otherList ) do
		-- 每天奖励
		local _reward = {}
		local _list = string.split( v.reward, "," )
		for j, u in ipairs( _list ) do
			local _data = string.split( u, "|" )
			_reward[#_reward + 1] = {
				itemType = _data[1],
				itemId = _data[2],
				itemNum = _data[3],
			}
		end
		self._rewardList[tonumber( v.id )] = _reward
	end

	self._time = tonumber( params.time ) or 0

	self._size = self:getContentSize()
end

function SpeedLayer:buildStatus( status )
	self._status = {}
	for i, v in ipairs( status ) do
		self._status[#self._status + 1] = {
			index = i,
			status = tonumber( v ),
		}
	end
	table.sort(self._status, function( a, b )
		if a.status == b.status then
			return a.index < b.index
		else
			return ( a.status + 1 )%3 > ( b.status + 1 )%3
		end
	end)
end

function SpeedLayer:initUI()
	-- tableview
	local tableview = zc.ZCTableView:create( cc.size( self._size.width, 403 ) )
    tableview:setBounceable( true )
    tableview:setInertia( true )
    tableview:setDirection( cc.SCROLLVIEW_DIRECTION_VERTICAL )
    tableview:setPosition( cc.p( 0, 60 ) )
    tableview:setDelegate()
    tableview:setVerticalFillOrder( cc.TABLEVIEW_FILL_TOPDOWN )
    local cellWidth = self._size.width
    local cellHeight = 160
    local function cellSizeForTable(table, index) 
        return cellHeight, cellWidth
    end
    local function tableCellAtIndex(table, index)
        local cell = table:dequeueCell()
        -- 创建模板
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
            self:buildCell( cell, cellWidth, cellHeight )
        end
        self:updateCell( cell, index + 1 )

        return cell
    end
    local function numberOfCellsInTableView()
    	return #self._status
    end
    tableview:registerScriptHandler( cellSizeForTable, cc.TABLECELL_SIZE_FOR_INDEX )
    tableview:registerScriptHandler( tableCellAtIndex, cc.TABLECELL_SIZE_AT_INDEX )
    tableview:registerScriptHandler( numberOfCellsInTableView, cc.NUMBER_OF_CELLS_IN_TABLEVIEW )
    self:addChild(tableview)
    self._tableview = tableview
    tableview:reloadData()

    -- bottom
    local _file = "res/Main/role/trinket/sellDi.png"
    local _rect = cc.rect(20, 10, 549, 71)
    if self._activityType == 1 then 
        _file = "res/Main/activity/newDi.png"
        _rect = cc.rect(25, 10, 30, 30)
    end
    local bottom = ccui.Scale9Sprite:create(_rect, _file)
    if self._activityType == 1 then 
        bottom:setContentSize(710, 62)
        bottom:setAnchorPoint(0.5, 0)
        bottom:setPosition(self._size.width*0.5, 3)
    else
        bottom:setContentSize(728, 68)
        bottom:setAnchorPoint(0, 0)
        bottom:setPosition(-2, -5)
    end
    self:addChild( bottom )
    local bottomSize = bottom:getContentSize()
    -- 活动时间
    local timeBg = ccui.Scale9Sprite:create( cc.rect( 12, 11, 14, 10 ), "res/Main/role/common/name_bg.png" )
    timeBg:setContentSize( 240, 30 )
    timeBg:setPosition( 153, bottomSize.height/2 )
    bottom:addChild( timeBg )
    local timeLabel = zc.createLabel({
    	text = zc.lang("activity_time_count_down") .. ":  "..zc.getTimer( self._time, 1 ),
        fontSize = 20,
        color = display.COLOR_TAB_NORMAL_COLOR1,
        color2 = display.COLOR_TAB_NORMAL_COLOR2,
        ap = cc.p( 0, 0.5 ),
        pos = cc.p( 37, bottomSize.height/2 ),
	})
    bottom:addChild( timeLabel )
    self._timeLabel = timeLabel
    self._timer = scheduler.scheduleGlobal(function()
    	if self._time > 0 then
    		self._time = self._time - 1
			timeLabel:setText( zc.lang("activity_time_count_down") .. ":  "..zc.getTimer( self._time, 1 ) )
		else
			if self._timer then
				scheduler.unscheduleGlobal( self._timer )
				self._timer = nil
			end
		end
	end, 1)
end

function SpeedLayer:buildCell( cell, cellWidth, cellHeight )
	-- bg
	local bg = cc.Sprite:create() 
	bg:setContentSize( 666, 156 )
	bg:setPosition( cellWidth/2, cellHeight/2 - 5 )
	cell:addChild( bg )
	cell._bg = bg
	local bgSize = bg:getContentSize()
	-- heroBg
	local iconBg = cc.Sprite:create( "res/Main/activity/speed/icon_bg.png" )
	iconBg:setAnchorPoint( 0, 0.5 )
	iconBg:setPosition( 5, bgSize.height/2 )
	bg:addChild( iconBg )
	-- hero
	local heroBg = cc.Sprite:create( "res/Main/hero/hero_item5.png" )
	heroBg:setScale( 0.85 )
	heroBg:setPosition( 68, bgSize.height/2 )
	bg:addChild( heroBg )
	local hero = cc.Sprite:create()
	hero:setScale( 1.1 )
	hero:setPosition( heroBg:getPosition() )
	bg:addChild( hero )
	cell._hero = hero
	-- passed
	local passed = cc.Sprite:create( "res/Main/activity/speed/passed.png" )
	passed:setAnchorPoint( 0, 0 )
	passed:setPosition( 10, 5 )
	bg:addChild( passed )
	cell._passed = passed
	-- title
	local title = cc.Sprite:create( "res/Main/pub/name_bg.png" )
	title:setAnchorPoint( 0, 1 )
	title:setPosition( 0, bgSize.height + 3 )
	bg:addChild( title )
	-- titleLabel
	local titleLabel = zc.createLabel({
        fontSize = 20,
        stroke = true,
        pixel = 1.5,
        color = display.COLOR_BLACK,
        color2 = display.COLOR_TAB_NORMAL_COLOR1,
        ap = cc.p( 0, 0.5 ),
        pos = cc.p( 5, title:getContentSize().height/2 ),
	})
	title:addChild( titleLabel )
	cell._titleLabel = titleLabel
	-- icon
	local icons = cc.Sprite:create()
	icons:setContentSize( 264, cellHeight )
	icons:setAnchorPoint( 0, 0.5 )
	icons:setPosition( 200, cellHeight/2 )
	bg:addChild( icons )
	cell._icons = icons
	-- btn
	local btn = zc.createCommomBtn({
		tag = 1,
		text = zc.lang("fetch_2"),
		pos = cc.p( 553, bgSize.height/2 ),
		endCallback = function()
			zc.sendHttp({
				apiName = "Speed_getReward",
				params = {rewardId = cell._index},
				successCallback = function(backData)
					self:refreshRedDot(backData)
					zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_FOODSRED, data = {}})
					backData.noAnimation = true
                	-- 道具
                	zc.createShowReward( backData )
                	-- 资源
                	PlayerData:updataData( backData )

					self:buildStatus( backData.status )
					self._tableview:reloadDataAndScrollToCurrentCell()
					self:updateRedDot()
				end,
			})
		end
	})
	bg:addChild( btn )
	cell._btn = btn
	-- 已领取
	local fetched = cc.Sprite:create( "res/Main/activity/monthSign/fetched.png" )
	fetched:setPosition( btn:getPosition() )
	bg:addChild( fetched )
	cell._fetched = fetched
end

--是否还有奖励领，用于刷新红点状态
function SpeedLayer:refreshRedDot(backData)
	for k,v in pairs(backData.status) do
		if tonumber(v) == 1 then
			PlayerData:updateRedDotData(4, 1)
			return
		end 
	end

	PlayerData:updateRedDotData(4, 0)
end


function SpeedLayer:updateCell( cell, index )
	local _status = self._status[index]
	cell._index = _status.index
	local _data = gameData.getDataFromCacheWithPrimaryKey("speed", _status.index)
	if not _data then
		return
	end
	cell._bg:setTexture( "res/Main/activity/cell_bg_"..( index % 3 )..".png" )
	cell._hero:setTexture( "res/Main/hero/head/hero_head_"..tostring( _data.iconId )..".png" )
	cell._titleLabel:setText( zc.lang("finish_tollgate") .. tostring(_data.name) )
	local _rewardData = self._rewardList[_status.index]
	self:refreshReward( cell._icons, _rewardData )
	if _status.status == 0 then
		-- 不可领取
		zc.setGray( cell._hero, false )
		cell._passed:setVisible( false )
		cell._btn:setVisible( true )
		cell._btn:setEnable( false )
		cell._btn:setText(zc.lang("un_finish_tollgate"))
		cell._fetched:setVisible( false )
	elseif _status.status == 1 then
		-- 可领取
		zc.setGray( cell._hero, false )
		cell._passed:setVisible( true )
		cell._btn:setVisible( true )
		cell._btn:setEnable( true )
		cell._btn:setText(zc.lang("fetch_2"))
		cell._fetched:setVisible( false )
	elseif _status.status == 2 then
		-- 已领取
		zc.setGray( cell._hero )
		cell._passed:setVisible( true )
		cell._btn:setVisible( false )
		cell._fetched:setVisible( true )
	end
end

function SpeedLayer:refreshReward( icons, data )
	icons:removeAllChildren()
	for i, v in ipairs( data or {} ) do
		local _icon = zc.createIconByData({
	        data = {
	            mainType = v.itemType,
	            type = v.itemId, 
	            id = v.itemId,
	            num = v.itemNum,
	        },
	        showDetailPop = true,
	        pos = cc.p( 88*( i - 0.5 ), icons:getContentSize().height/2 ),
		})
		_icon:setScale( 0.65 )
		icons:addChild( _icon )
	end
end

-- 刷新红点
function SpeedLayer:updateRedDot()
	local _status = false
	for i, v in ipairs( self._status ) do
		if v.status == 1 then
			_status = true
			break
		end
	end
	if _status ~= PlayerData._activitySpeedStatus then
		PlayerData._activitySpeedStatus = _status
		zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_ACTIVITY_REDDOT, data = {id = 2}})
		zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_REDORBUBBLE_CHANGE, data = {tag = "activity"}})
	end
end

return SpeedLayer