--[[
-- 国家排行
-- @author lph
-- Creation  2016-4-13
]]
local CountryRankLayer = class("CountryRankLayer",function ()
	local layer = cc.Sprite:create()
    layer:setContentSize( 565, 464 )
    layer:setAnchorPoint(cc.p(0,0))
    return layer
end)

function CountryRankLayer:create(params)
	return CountryRankLayer.new(params)
end

function CountryRankLayer:ctor(params)
    self:initData(params)
	self:initUI()
end

function CountryRankLayer:initData(params)
	self._countryData = params.countrys
    self:countrySort()
    -- self._country_name = params.name                      --国家名称
    -- self._country_level = params.lv                       --国家等级
    -- self._country_monarch_name = params.monarchIdName     --君主名称
    -- self._country_member = params.member                  --国家成员数
    -- self._country_memberLimit = params.memberLimit        --国家成员数
    -- self._country_createTime = params.createTime          --国家创建时间
    self._size = self:getContentSize()
    --组织头数据
    self._names = {zc.lang("country_rank"),zc.lang("country_name_1"),zc.lang("level"),zc.lang("country_monarch"),zc.lang("country_number")}
    -- dump(self._countryData, "---self._countryData---")

    local num = table.nums(self._countryData)
    self._country_member_num = num or 0
end

--国家排名
function CountryRankLayer:countrySort()
    local _newInfoList = {}
    for k,v in pairs(self._countryData) do
        _newInfoList[#_newInfoList+1] = v
    end
    local function _comp(a,b)
        if tonumber(a.lv) == tonumber(b.lv) then
            if tonumber(a.countryFighting) == tonumber(b.countryFighting) then
                if tonumber(a.member) == tonumber(b.member) then
                    return tonumber(a.createTime) > tonumber(b.createTime)
                else
                    return tonumber(a.member) > tonumber(b.member)
                end
            else
                return tonumber(a.countryFighting) > tonumber(b.countryFighting)
            end
        else
            return tonumber(a.lv) > tonumber(b.lv)
        end
    end
    table.sort(_newInfoList,_comp)
    self._countryData = _newInfoList
end

function CountryRankLayer:initUI()
    local rank_title_bg = zc.createSprite( "res/Main/country/main/rank_title_bg.png" )
    rank_title_bg:setPosition(self._size.width/2, self._size.height-20)
    self:addChild(rank_title_bg)
    local _posY = rank_title_bg:getContentSize().height/2
    local namePosX = {50,180,283,383,509}
    for i=1,#self._names do
        local _label = zc.createLabel({
            text = self._names[i],
            fontSize = 22,
            ap = cc.p(0.5,0.5),
            pos = cc.p(namePosX[i] , _posY),
            color = cc.c3b(180,140,108),
        })
        rank_title_bg:addChild(_label)
    end
    self:initRankList()
end

function CountryRankLayer:initRankList()
    local _tableSize = cc.size(565, 420)
    local _tableView = zc.ZCTableView:create(_tableSize)
    _tableView:setPosition(0, 0)
    _tableView:setInertia(true)
    _tableView:setBounceable(true)
    _tableView:setDirection(zctech.SCROLLVIEW_DIRECTION_VERTICAL)
    _tableView:setDelegate()
    _tableView:setVerticalFillOrder(zctech.TABLEVIEW_FILL_TOPDOWN)
    self:addChild(_tableView)
    self._countryTable = _tableView

    local _cellSize = cc.size(565, 90)

    local function numberOfCellsInTableView( table )
        return self._country_member_num
    end
    local function cellSizeForTable( table, index )
        return _cellSize.height , _cellSize.width
    end
    local function tableCellAtIndex( table, index )
        local cell = table:dequeueCell()
        if not cell then
            cell = zc.ZCTableViewCell:new()
            cell:setContentSize(_cellSize)
            self:createCell(cell,index+1)
        end
        self:updateCell(cell,index+1)

        return cell
    end
    _tableView:registerScriptHandler(numberOfCellsInTableView, cc.NUMBER_OF_CELLS_IN_TABLEVIEW )
    _tableView:registerScriptHandler(cellSizeForTable, cc.TABLECELL_SIZE_FOR_INDEX )
    _tableView:registerScriptHandler(tableCellAtIndex, cc.TABLECELL_SIZE_AT_INDEX )
    _tableView:reloadData()
end
function CountryRankLayer:createCell( cell, index )
    local cellSize = cell:getContentSize()
    local posyMiddle = cellSize.height/2
    local cell_img = zc.createSprite()
    cell_img:setAnchorPoint(0.5, 0.5)
    cell_img:setPosition(cellSize.width/2, posyMiddle)
    cell:addChild(cell_img)
    local top3 = zc.createSprite()
    top3:setPosition(58, posyMiddle)
    cell_img:addChild(top3)
    local rankNum = zc.createFntLabel({
        fnt = "res/Main/arena/rank/fnt/arenaRank_num.fnt",
        pos = cc.p( 61, posyMiddle ),
    })
    cell_img:addChild( rankNum )
    local labPosX = {180,283,383}
    for i = 1, 3 do
        local cellLab = zc.createLabel({
            text = "",
            stroke = false,
            fontSize = 20,
            fontName = zc.getFont(1),
            pos = cc.p(labPosX[i], posyMiddle),
            color = cc.c3b(76,18,18),
        })
        cellLab:setName("cellLab"..i)
        cell_img:addChild(cellLab)
    end
    local memberNumLab = zc.createLabel({
        text = "0/50",
        outLine = true,
        fontSize = 22,
        fontName = zc.getFont(1),
        pos = cc.p(509, posyMiddle),
        color = display.COLOR_WHITE,
        color2 = display.COLOR_BLACK,
    })
    cell_img:addChild(memberNumLab)
    

    cell._cell_img = cell_img
    cell._top3 = top3
    cell._rankNum = rankNum
    cell._memberNumLab = memberNumLab

end
function CountryRankLayer:updateCell( cell, index )

    local cell_img = cell._cell_img
    local top3 = cell._top3
    local rankNum = cell._rankNum
    local memberNumLab = cell._memberNumLab
    local rankNum = cell._rankNum

    top3:setVisible(false)
    rankNum:setVisible(false)
    local imgId = index < 4 and index or 4
    local imgPath = "res/Main/country/main/country_rank_"..imgId..".png"
    cell_img:setTexture(imgPath)
    if index < 4 then
        local top3Path = "res/Main/arena/rank/icon_"..index..".png"
        top3:setVisible(true)
        top3:setTexture(top3Path)
    else
        rankNum:setVisible(true)
        rankNum:setString( index )
    end
    local _country_data = self._countryData[index]
    for i = 1,3 do
        local cellLab = cell_img:getChildByName("cellLab"..i)
        local _text = ""
        if i == 1 then
            _text = _country_data.name
        elseif i == 2 then
            _text = _country_data.lv
        elseif i == 3 then
            _text = _country_data.monarchIdName
        end
        cellLab:setText(_text)
    end
    memberNumLab:setText(_country_data.member.."/".._country_data.memberLimit)
    if tonumber(_country_data.member) >= tonumber(_country_data.memberLimit) then
        memberNumLab:setColor(display.COLOR_RED)
    else
        memberNumLab:setColor(display.COLOR_GREEN)
    end
end
return CountryRankLayer