--[[
	武将列表界面
	唐实聪
	2016.5.9
]]
local HeroListLayer = class("HeroListLayer", function()
	return ZCDialog:create()
end)

function HeroListLayer:create( params )
	return HeroListLayer.new( params )
end

function HeroListLayer:ctor( params )
	self:initData( params )
	self:initUI()
	self:refreshData()
	self:refreshTab()
end

function HeroListLayer:selfFresh()
	self:refreshData()
	-- 构造当前界面数据
	self:buildTabData()
	-- 清空cell，重新创建
	self:removeCell()
	self._heroTableview:reloadDataAndScrollToCurrentCell()
end

function HeroListLayer:onEnter()
	if self._init then
		-- 重新取数据
		self:selfFresh()
	end
	self._init = true
	performWithDelay(self, function()
		if self._guideHandFlag then
			self._guideHandFlag = false
			local _guideHand = zc.createSpine({
	            fileName = "shou",
	            actName = "shou",
	            scale = 0.8
	        })
	        _guideHand:setPosition(cc.pMul(cc.pFromSize(self._closeButton:getContentSize()), 0.5))
	        self._closeButton:addChild(_guideHand, 10)
	        performWithDelay(_guideHand, function()
                _guideHand:removeFromParent()
                _guideHand = nil
            end, 4)
		end
	end, 0.01)
end

function HeroListLayer:onCleanup()
	self:removeCell()
	self:removeAllChildren()
    helper.collectMemory()
end

function HeroListLayer:initData( params )
	-- 拥有武将
	self._ownCell = {}
	-- 未拥有武将
	self._buyCell = {}
	
	self._tabIndex = 1

	-- 主角的id
	self._mainHeroId = tonumber( PlayerData.info.heroId ) or 0

	-- tab数据
	self._tabData = {
		[1] = {
			name = zc.lang("all"),
			weaponType = 0,
		},
		[2] = {
			name = zc.lang("long_handle"),
			weaponType = 1,
		},
		[3] = {
			name = zc.lang("single_hand"),
			weaponType = 2,
		},
		[4] = {
			name = zc.lang("staff"),
			weaponType = 3,
		},
		[5] = {
			name = zc.lang("sword"),
			weaponType = 4,
		},
		[6] = {
			name = zc.lang("fan"),
			weaponType = 5,
		},
		[7] = {
			name = zc.lang("magic_ball"),
			weaponType = 6,
		},
	}

	self._ownHeroType = {}
	self._buyHeroType = {}

	self._size = self:getContentSize()
	-- tab宽度
	self._tabWidth = self._size.width - 1024
	-- 所有商店武将
	self._shopHeroList = params or {}

end

function HeroListLayer:initUI()
    -- 通用背景
    local _commonBg = cc.Sprite:create( "res/Main/common/common_bg.jpg" )
    _commonBg:setPosition( self._size.width/2, self._size.height/2 )
    self:addChild( _commonBg )
    zc.setBgSize( _commonBg )

	-- 背景
	local _bgWidth = 980
	local _bgHeight = 530
	local _bg = zc.createNormalPop({
        tag = 2,
        src = "res/Main/role/list/bg.jpg",
        width = _bgWidth,
        height = _bgHeight,
        showSide = true,
    })
    _bg:setScaleX( _bgWidth/_bg:getContentSize().width )
    _bg:setScaleY( _bgHeight/_bg:getContentSize().height )
	_bg:setPosition( self._size.width/2 - 40, self._size.height/2 )
	self:addChild( _bg )
	local bg = cc.Sprite:create()
	bg:setContentSize( _bgWidth, _bgHeight )
	bg:setPosition( _bg:getPosition() )
	self:addChild( bg )
	self._bg = bg
	self._bgSize = bg:getContentSize()

	-- 标签
	self:initTab()

	-- tableview
	self:initTableview()

    -- 花
    local _flower_l_u = cc.Sprite:create( "res/Main/common/flower_l_u.png" )
    _flower_l_u:setAnchorPoint( 0, 1 )
    _flower_l_u:setPosition( 0, self._size.height )
    self:addChild( _flower_l_u )
    local _flower_r_u = cc.Sprite:create( "res/Main/common/flower_r_u.png" )
    _flower_r_u:setAnchorPoint( 1, 1 )
    _flower_r_u:setPosition( self._size.width, self._size.height )
    self:addChild( _flower_r_u )
    local _flower_r_d = cc.Sprite:create( "res/Main/common/flower_r_d.png" )
    _flower_r_d:setAnchorPoint( 1, 0 )
    _flower_r_d:setPosition( self._size.width, 0 )
    self:addChild( _flower_r_d )

	-- 空
	local empty = cc.Sprite:create( "res/Main/common/empty.png" )
	empty:setPosition( ( self._size.width - self._tabWidth )/2, self._bgSize.height/2 )
	bg:addChild( empty )
	self._empty = empty
	empty:setVisible( false )

	-- title
	local title = cc.Sprite:create( "res/Main/role/list/title.png" )
	title:setAnchorPoint( 0, 0.5 )
	title:setPosition( 0, self._size.height/2 + 250 )
    self:addChild( title )

	-- 返回
    local back = zc.createTopBackButton({
        pos = cc.p(zc.width - 40, zc.height - 40), 
        listener = function () 
            LayerManager.removeLayout()
        end,
    })
    self:addChild( back )
    self._closeButton = back
end
function HeroListLayer:initTab()
	-- tab
	for i, v in ipairs( self._tabData ) do
        -- 兵器图标类型
        local weaponType = v.weaponType == 0 and 1 or v.weaponType
        local _normal = cc.Sprite:create( "res/Main/common/button/tab_btn_noraml.png" )
        local _normal_label = zc.createLabel({
        	text = v.name,
            color = cc.c3b( 122, 42, 0 ),
            color2 = cc.c3b( 255, 232, 128 ),
            outLine = true,
            pixel = 0,
            fontSize = 24,
            pos = cc.p( _normal:getContentSize().width/2 + 12, _normal:getContentSize().height/2 ),
        })
        _normal:addChild( _normal_label )
        local _selected = cc.Sprite:create( "res/Main/common/button/tab_btn_select.png" )
        local _selected_label = zc.createLabel({
        	text = v.name,
            color = display.COLOR_WHITE,
            color2 = cc.c3b( 72, 37, 0 ),
            outLine = true,
            pixel = 1,
            fontSize = 24,
            pos = cc.p( _selected:getContentSize().width/2 + 12, _selected:getContentSize().height/2 ),
        })
        _selected:addChild( _selected_label )
        local btn = zc.createPushButton({
        	normalNode = _normal,
        	selectedNode = _selected,
            pos = cc.p(self._bg:getPositionX() + self._bg:getContentSize().width/2 + 1, self._bg:getPositionY() + 275 - 70*i ),
            anchor = cc.p(0, 0.5),
            endCallback = function() end,
        })
		btn:setTouchEndedCall(function()
			if self._tabIndex ~= i then
				if self._tabBtn then
					self._tabBtn:setSelected( false )
				end
				self._tabBtn = btn
				self._tabBtn:setSelected( true )
				self._tabIndex = i
				self:refreshTab()
			end
		end)
		self:addChild( btn, 1 )
        local icon_normal = cc.Sprite:create( zc.getHeroTypeImg( weaponType ) )
        icon_normal:setAnchorPoint( 0, 0.5 )
        icon_normal:setPosition( 1, btn:getContentSize().height/2 )
        btn:addChild( icon_normal )

		if self._tabIndex == i then
			btn:setSelected( true )
			self._tabBtn = btn
		end
	end
end

function HeroListLayer:initTableview()
	local _tableviewWidth = 968
	local _tableviewHeight = 465
	local heroTableview = zc.ZCTableView:create( cc.size( _tableviewWidth, _tableviewHeight ) )
    heroTableview:setBounceable( true )
    heroTableview:setInertia( true )
    heroTableview:setDirection( cc.SCROLLVIEW_DIRECTION_VERTICAL )
    heroTableview:setPosition( cc.p( 6, 10 ) )
    heroTableview:setDelegate()
    heroTableview:setVerticalFillOrder( cc.TABLEVIEW_FILL_TOPDOWN )
    local cellWidth = _tableviewWidth
    local titleHeight = 48
    local cellHeight = 145
    local function cellSizeForTable(table, index)
    	if index == 0 or index == math.ceil( #self._ownHeroData/2 ) + ( #self._ownHeroData == 0 and 0 or 1 ) then
    		-- 标题
        	return titleHeight, cellWidth
        else
        	-- 武将
        	return cellHeight, cellWidth
        end
    end
    local function tableCellAtIndex(table, index)
        local cell = table:dequeueCell()
        -- 创建模板
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
        end
        cell:removeAllChildren()

        if #self._ownHeroData > 0 and index == 0 then
        	-- 已拥有将领标题
        	local lace_left = cc.Sprite:create( "res/Main/role/list/lace_light.png" )
        	lace_left:setPosition( cellWidth/2 - 105, titleHeight/2 )
        	cell:addChild( lace_left )
        	local lace_right = cc.Sprite:create( "res/Main/role/list/lace_light.png" )
        	lace_right:setFlippedX( true )
        	lace_right:setPosition( cellWidth/2 + 105, titleHeight/2 )
        	cell:addChild( lace_right )
        	local title = zc.createLabel({
		        text = zc.lang("already_have_role"),
		        fontSize = 25,
		        ttf = zc.getFont(1),
		        ap = cc.p(0.5, 0.5),
		        pos = cc.p( cellWidth/2, titleHeight/2 ),
		        outLine = true,
		        pixel = 2,
		        color = cc.c3b( 238, 207, 13 ),
    		})
        	cell:addChild( title )
    	elseif #self._ownHeroData > 0 and index <= math.ceil( #self._ownHeroData/2 ) then
    		-- 已拥有武将
    		for i = 1, 2 do
    			local data = self._ownHeroData[( index - 1 )*2 + i]
    			if data then
    				local heroCell = nil
    				if data.canCompose then
    					heroCell = self._buyCell[tonumber( data.id )]
    				else
    					heroCell = self._ownCell[tonumber( data.id )]
    				end
    				if not heroCell then
    					-- 没创建
	    				if data.canCompose then
	    					heroCell = self:buildBuyCell( data )
	    					self._buyCell[tonumber( data.id )] = heroCell
	    				else
	    					heroCell = self:buildOwnCell( data )
	    					self._ownCell[tonumber( data.id )] = heroCell
	    				end
    					heroCell:retain()
    				end
    				if heroCell.btn and not tolua.isnull( heroCell.btn ) then
    					heroCell.btn:setScale( 1 )
    				end
					heroCell:setPosition( cellWidth/4*( 2*i - 1 ), cellHeight/2 )
					heroCell:removeFromParent()
					heroCell._bg:setScale( 1 )
					cell:addChild( heroCell )
					--新手引导
					local _currentGID = getGuideManager():getCurrentGID()
				    if tonumber(data.heroId) == GuideHeroId.BTN_SELECT_HERO 
				      and inArray(_currentGID, GuideGroup.BTN_SELECT_HERO) then
				    	heroCell.btn:setSwallowTouches(true)
				    	self._heroCell = heroCell
			    	elseif (_currentGID == GuideKey.KEY_11402 
			    	  or _currentGID == GuideKey.KEY_12309
			    	  or _currentGID == GuideKey.KEY_14303) 
			    	  and tonumber(data.id) == tonumber(PlayerData:getBaseInfoByTag("heroId")) then
				    	heroCell.btn:setSwallowTouches(true)
				    	self._heroCell = heroCell
					end

					if heroCell.numLab then
						heroCell.numLab:setVisible(false)
					end
					if  heroCell.progress then
						heroCell.progress:setVisible(false)
					end
					if  heroCell.progress2 then
						heroCell.progress2:setVisible(true)
					end
    				if heroCell.canComposeImg then
    					heroCell.canComposeImg:setVisible(true)
    				end
    				if heroCell.canComposeImg2 then
    					heroCell.canComposeImg2:setVisible(true)
    				end
    			end
    		end
        elseif #self._buyHeroData > 0 and index == math.ceil( #self._ownHeroData/2 ) + ( #self._ownHeroData == 0 and 0 or 1 ) then
        	-- 未拥有将领标题
        	local lace_left = cc.Sprite:create( "res/Main/role/list/lace_dark.png" )
        	lace_left:setPosition( cellWidth/2 - 105, titleHeight/2 )
        	cell:addChild( lace_left )
        	local lace_right = cc.Sprite:create( "res/Main/role/list/lace_dark.png" )
        	lace_right:setFlippedX( true )
        	lace_right:setPosition( cellWidth/2 + 105, titleHeight/2 )
        	cell:addChild( lace_right )
        	local title = zc.createLabel({
		        text = zc.lang("un_have_role"),
		        fontSize = 25,
		        ttf = zc.getFont(1),
		        ap = cc.p(0.5, 0.5),
		        pos = cc.p( cellWidth/2, titleHeight/2 ),
		        outLine = true,
		        pixel = 2,
    		})
        	cell:addChild( title )
    	elseif #self._buyHeroData > 0 and index > math.ceil( #self._ownHeroData/2 ) + ( #self._ownHeroData == 0 and 0 or 1 ) then
    		-- 未拥有武将
    		for i = 1, 2 do
    			local data = self._buyHeroData[( index - math.ceil( #self._ownHeroData/2 ) - ( #self._ownHeroData == 0 and 0 or 1 ) - 1 )*2 + i]
    			if data then
    				local heroCell = self._buyCell[tonumber( data.id )]
    				if not heroCell then
    					-- 没创建
    					heroCell = self:buildBuyCell( data )
    					heroCell:retain()
						self._buyCell[tonumber( data.db.id )] = heroCell
    				end
    				if heroCell.btn and not tolua.isnull( heroCell.btn ) then
    					heroCell.btn:setScale( 1 )
    				end
					heroCell:setPosition( cellWidth/4*( 2*i - 1 ), cellHeight/2 )
					heroCell:removeFromParent()
					heroCell._bg:setScale( 1 )
					cell:addChild( heroCell )
					if heroCell.numLab and heroCell.progress then
						heroCell.numLab:setVisible(true)
						heroCell.progress:setVisible(true)
						local _curNum = tonumber(data.fragCurNum) or 0
						local _maxNum = tonumber(data.fragMaxNum) or 1
						heroCell.numLab:setString(_curNum .. "/" .. _maxNum)
						local _width = _curNum/_maxNum*heroCell.progress.width
						_width = _width > heroCell.progress.width and heroCell.progress.width or _width
						heroCell.progress:setContentSize(_width, heroCell.progress.height)
    				end
    				if heroCell.canComposeImg then
    					heroCell.canComposeImg:setVisible(false)
    				end
    				if heroCell.canComposeImg2 then
    					heroCell.canComposeImg2:setVisible(false)
    				end
					if  heroCell.progress2 then
						heroCell.progress2:setVisible(false)
					end
    			end
    		end
		end

        return cell
    end
    local function numberOfCellsInTableView()
    	local num = 0
    	if #self._ownHeroData ~= 0 then
    		num = num + math.ceil( #self._ownHeroData/2 ) + 1
    	end
    	if #self._buyHeroData ~= 0 then
    		num = num + math.ceil( #self._buyHeroData/2 ) + 1
    	end
        return num
    end
    heroTableview:registerScriptHandler(cellSizeForTable, cc.TABLECELL_SIZE_FOR_INDEX)
    heroTableview:registerScriptHandler(tableCellAtIndex, cc.TABLECELL_SIZE_AT_INDEX)
    heroTableview:registerScriptHandler(numberOfCellsInTableView, cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
    self._bg:addChild( heroTableview )
    self._heroTableview = heroTableview
end

-- 重新从player中取数据
function HeroListLayer:refreshData()
	-- 已拥有武将
	local ownHero = {}
	self._ownHeroList = {}
	-- 主角
	self._mainHeroData = {}
	local _houseData = PlayerData:getHouseInfoByHouseId(9) or {}
	local _houseLevel = tonumber(_houseData.level) or 1
	local _myLevel = tonumber(PlayerData.info.level) or 1
	local _bookList = gameData.getAllDataWithNoClone("hero_handbook_card")
	local _openLevel = 0
	for k,v in pairs(_bookList) do
		local _level = tonumber(v.level) or 1
		local _plevel = tonumber(v.plevel) or 1
		if _level <= _houseLevel and _plevel <= _myLevel then
			local _pid = tonumber(v.id) or 1
			_openLevel = _openLevel < _pid and _pid or _openLevel
		end
	end

	for i, v in ipairs( PlayerData:getGeneralInfo() ) do
		if tonumber( v.id ) ~= self._mainHeroId then
			self._ownHeroList[#self._ownHeroList + 1] = v
			ownHero[tonumber( v.heroId )] = true
		else
			-- 主角
			self._mainHeroData = v
		end
	end
	local _mainWeaponData = PlayerData:getWeaponsInfoById( self._mainHeroData.id ) or {}
	self._mainWeaponType = tonumber( _mainWeaponData.type ) or 1
	-- 未拥有武将
	self._buyHeroList = {}

	local _bookCardList = gameData.getAllDataWithNoClone("hero_handbook_info")
	for i, v in pairs( _bookCardList ) do
		if not ownHero[tonumber( v.generalid )] then
			local data = gameData.getDataFromCacheWithPrimaryKey("hero", v.generalid)
			if next( data ) then
				local _saveData = {}
				_saveData.id = data.id
				_saveData.db = data
				_saveData.canBuy = true
				local _handbook = tonumber(v.handbook) or 1
				if _handbook > _openLevel then
					_saveData.canBuy = false
				else
					local _condition = tonumber(v.condition) or 0
					if _condition ~= 0 then
						local _info = gameData.getDataFromCacheWithPrimaryKey("hero_handbook_info", _condition)
						if not ownHero[tonumber( _info.generalid )] then
							_saveData.canBuy = false
						end
					end
				end
				_saveData.canCompose = 0
				if _saveData.canBuy then
					_saveData.fragCurNum = PlayerData:getFragmentNumByHeroId(data.id)
					local _dbdb = gameData.getDataFromCacheWithPrimaryKey("hero_change_card", data.qualifications)
					_saveData.fragMaxNum = tonumber(_dbdb.compoundNum) or 0
					if _saveData.fragCurNum ~= 0 and _saveData.fragCurNum >= _saveData.fragMaxNum then
						_saveData.canCompose = 1
					end
				end
				if _saveData.canCompose == 1 then
					self._ownHeroList[#self._ownHeroList + 1] = _saveData
				else
					self._buyHeroList[#self._buyHeroList + 1] = _saveData
				end
			end
		end
	end
	self._ownHeroType = {}
	self._buyHeroType = {}
end

-- 构造当前tab的数据
function HeroListLayer:buildTabData()
	-- 兵器类型
	local weaponType = self._tabData[self._tabIndex].weaponType
	-- 拥有武将
	self._ownHeroData = self._ownHeroType[weaponType]
	if not self._ownHeroData then
		self._ownHeroData = {}
		if weaponType == 0 then
			self._ownHeroData = self._ownHeroList
		else
			for i, v in ipairs( self._ownHeroList ) do
				if tonumber( v.weaponType ) == weaponType
				  or (v.db and tonumber( v.db.weaponType ) == weaponType) then
					self._ownHeroData[#self._ownHeroData + 1] = v
				end
			end
		end
		table.sort(self._ownHeroData, function( a, b )
				local _canComposeA = tonumber(a.canCompose) or 0
				local _canComposeB = tonumber(b.canCompose) or 0
				if _canComposeA ~= _canComposeB then
					return _canComposeA > _canComposeB
				end
				if _canComposeA == 1 then
					local _dbA = a.db or {}
					local _dbB = b.db or {}
					local _qualificationsA = tonumber(_dbA.qualifications) or 0
					local _qualificationsB = tonumber(_dbB.qualifications) or 0
					if _qualificationsA ~= _qualificationsB then
						return _qualificationsA > _qualificationsB
					end
					local _idA = tonumber( _dbA.id ) or 0
					local _idB = tonumber( _dbB.id ) or 0
					return _idA < _idB
				end
				return tonumber( a.fighting ) > tonumber( b.fighting )
			-- end
		end)
		-- 主角
		if self._mainWeaponType == weaponType or weaponType == 0 then
			table.insert(self._ownHeroData, 1, self._mainHeroData)
		end
		self._ownHeroType[weaponType] = self._ownHeroData
	end
	-- dump( self._ownHeroData, "self._ownHeroData" )
	-- 未拥有武将
	self._buyHeroData = self._buyHeroType[weaponType]
	if not self._buyHeroData then
		self._buyHeroData = {}
		if weaponType == 0 then
			self._buyHeroData = self._buyHeroList
		else
			for i, v in ipairs( self._buyHeroList ) do
				if tonumber( v.weaponType ) == weaponType then
					self._buyHeroData[#self._buyHeroData + 1] = v
				end
			end
		end
		table.sort(self._buyHeroData, function( a, b )
			if a.canBuy ~= b.canBuy then
				return a.canBuy
			end
			local _qualificationsA = tonumber(a.db.qualifications) or 0
			local _qualificationsB = tonumber(b.db.qualifications) or 0
			if _qualificationsA ~= _qualificationsB then
				return _qualificationsA > _qualificationsB
			end
			return tonumber( a.db.id ) < tonumber( b.db.id )
		end)
		self._buyHeroType[weaponType] = self._buyHeroData
	end
	-- dump( self._buyHeroData, "self._buyHeroData" )
end

-- 刷新当前tab
function HeroListLayer:refreshTab()
	self:buildTabData()
	self._heroTableview:reloadData()

	if #self._ownHeroData == 0 and #self._buyHeroData == 0 then
		self._empty:setVisible( true )
	else
		self._empty:setVisible( false )
	end
	--新手引导
	zc.addGuideBtn(self._heroCell)
end

-- 构造已有武将
function HeroListLayer:buildOwnCell( data )
	-- dump( data, "data" )
    local _id = tonumber( data.id ) or 0
    local isMain = self._mainHeroId == _id
	local cellBg = cc.Sprite:create()
	local path = "res/Main/role/list/"..zc.getHeroColorByQuality( data.quality )..".png"
	local bg = cc.Sprite:create( path )
	local bgSize = bg:getContentSize()
	cellBg:setContentSize( bgSize )
	-- 武将
    local _heroPath = string.format("res/Main/hero/list/%s.png", data.picture)
    if isMain then
        -- 主角
        local _head = nil
        local _body = nil
        _head, _body, _heroPath = PlayerData:getMainRoleHeadImg()
    end
    if not zc.checkFileExist( _heroPath ) then
        _heroPath = "res/Main/hero/list/1.png"
    end
	local heroSp = cc.Sprite:create( _heroPath )
	heroSp:setScale(0.4436)
	heroSp:setAnchorPoint( 0, 0.5 )
	heroSp:setPosition( 1, bgSize.height/2 )
	bg:addChild( heroSp )
	
    -- 星星
    local starNum = tonumber( data.star or 0 )
    if starNum ~= 0 then
	    local starBg = cc.Sprite:create( "res/Main/task/task_treasureBox_bg.png" )
	    starBg:setScaleX( 144/starBg:getContentSize().width )
	    starBg:setScaleY( 33/starBg:getContentSize().height )
	    starBg:setPosition( 95, 20 )
	    bg:addChild( starBg )
	    local starShowNum = ( starNum - 1 )%5 + 1
	    local starSrcData = {
	        "res/Main/common/common_hero_star_2.png",
	        "res/Main/common/common_hero_star_1.png",
	        "res/Main/role/starup/star_blue.png",
	        "res/Main/role/starup/star_purple.png",
	    }
	    local starSrc = starSrcData[math.ceil( starNum/5 ) + 1]
	    local spaceX = 18
	    local beginX = starBg:getPositionX() - spaceX*3
	    local beginY = starBg:getPositionY()
	    for i = 1, starShowNum do
	        local star = cc.Sprite:create( starSrc )
	        star:setPosition( beginX + i*spaceX, beginY )
	        star:setScale( 0.7 )
	        bg:addChild( star )
	    end
	end

	-- 称号
	local title = zc.createLabel({
        text = data.title,
        fontSize = 18,
        pos = cc.p( bgSize.width - 120, bgSize.height - 25 ),
        color = cc.c3b( 76, 18, 18 ),
	})
    bg:addChild( title )
	local titleLeft = cc.Sprite:create( "res/Main/common/lace.png" )
    titleLeft:setAnchorPoint( 1, 0.5 )
    titleLeft:setPosition( title:getPositionX() - title:getContentSize().width/2, title:getPositionY() )
    bg:addChild( titleLeft )
    local titleRight = cc.Sprite:create( "res/Main/common/lace.png" )
    titleRight:setAnchorPoint( 0, 0.5 )
    titleRight:setPosition( title:getPositionX() + title:getContentSize().width/2, title:getPositionY() )
    titleRight:setFlippedX( true )
    bg:addChild( titleRight )

    -- 名字
    local nameBgWidth = 214
	local nameBgHeight = 32
	local nameBg = ccui.Scale9Sprite:create( cc.rect( 15, 12, 163, 8 ), "res/Main/common/popBg/di_properties.png" )
	nameBg:setContentSize( nameBgWidth, nameBgHeight )
	nameBg:setPosition( bgSize.width - 127, 77 )
	bg:addChild( nameBg )
    -- 兵器图标
    local _weaponType = 0
    local _nameText = ""
    if isMain then
    	-- 主角
    	_weaponType = self._mainWeaponType
    	_nameText = PlayerData.info.userName
    else
    	-- 武将
    	_weaponType = data.weaponType
    	_nameText = data.name
    end
    local _newAdvance = tonumber(data.newAdvance) or 0
    if _newAdvance > 0 then
        _nameText = _nameText .. "+" .. _newAdvance
    end
    local weaponIcon = cc.Sprite:create( zc.getHeroTypeImg( _weaponType ) )
    weaponIcon:setPosition( 0, nameBgHeight/2 )
	nameBg:addChild( weaponIcon )
	local _levelText = ""
	local _reincarnate = tonumber( data.reincarnate ) or 0
	if _reincarnate > 0 then
		_levelText = _levelText.._reincarnate.. zc.lang("turn") .. " "
	end
	_levelText = _levelText..zc.getLevelTipShow()..data.level
	-- 武将名字
	local name = zc.createLabel({
        text = _levelText.._nameText,
        fontSize = 20,
        color = cc.c3b( 255, 236, 203 ),
        pos = cc.p( nameBgWidth/2 + 5, nameBgHeight/2 ),
        outLine = true,
        pixel = 1,
	})
	nameBg:addChild( name )
	-- 战斗力
    local fightBgWidth = 214
	local fightBgHeight = 32
	local fightBg = ccui.Scale9Sprite:create( cc.rect( 15, 12, 163, 8 ), "res/Main/common/popBg/di_properties.png" )
	fightBg:setContentSize( fightBgWidth, fightBgHeight )
	fightBg:setPosition( bgSize.width - 127, 36 )
	bg:addChild( fightBg )
    local fightingSp = cc.Sprite:create( "res/Main/role/list/fight.png" )
    fightingSp:setPosition( 0, fightBgHeight/2 )
	fightBg:addChild( fightingSp )
	-- 战斗力数字
	local fightingNum = zc.createFntLabel({
		text = data.fighting,
        fnt = "res/Main/common/fnt/fight_change.fnt",
        pos = cc.p( fightBgWidth/2 + 5, fightBgHeight/2 ),
        addwidth = -10,
    })
    fightingNum:setScale( 0.7 )
    fightBg:addChild( fightingNum )

    -- 框
    local frame = ccui.Scale9Sprite:create( cc.rect( 13, 60, 9, 62 ), "res/Main/common/frame_s.png" )
    frame:setContentSize( bgSize.width, bgSize.height + 2 )
    frame:setPosition( bgSize.width/2, bgSize.height/2 )
    bg:addChild( frame )
	-- 资质
	local _zizhiPos = cc.p(23,25)
	local qualificationsBg2 = cc.Sprite:create( "res/Main/role/qualifications_bg2.png" )
	-- qualificationsBg2:setScale( 0.45 )
	qualificationsBg2:setPosition( _zizhiPos )
	bg:addChild( qualificationsBg2 )
	local qualificationsBg = cc.Sprite:create( "res/Main/role/qualifications_bg.png" )
	qualificationsBg:setScale( 0.45 )
	qualificationsBg:setPosition( _zizhiPos )
	bg:addChild( qualificationsBg )
    local talentBg = zc.createSprite("res/Main/talent/talentBg.png")
    talentBg:setPosition(_zizhiPos)
    bg:addChild(talentBg)
    talentBg:setScale(0.2)
	local qualificationsSp = cc.Sprite:create( zc.getHeroQualificationsPath( data.qualifications, 2 ) )
	qualificationsSp:setPosition( _zizhiPos )
	qualificationsSp:setScale( 0.55 )
	bg:addChild( qualificationsSp )

	-- btn
	local btn = zc.createPushButton({
		normalNode = bg,
		touchSize = bgSize,
		pos = cc.p( bgSize.width/2, bgSize.height/2 ),
		needSwallow = false,
		touchScale = 0.95,
		needEnableWhenMoving = true,
		endCallback = function()
			cellBg.btn:setSwallowTouches(false)
            self:guideFunc()
			zc.createRoleScene({id = data.id})
		end
	})
	cellBg:addChild( btn )
	cellBg.btn = btn
	cellBg._bg = bg

	-- 红点
	local _redPoint = cc.Sprite:create( "res/Main/common/common_red_point.png" )
    _redPoint:setAnchorPoint( 1, 1 )
    _redPoint:setPosition( bgSize.width + 5, bgSize.height + 5 )
    bg:addChild( _redPoint )
    cellBg._redPoint = _redPoint

	local _flag = self:refreshRedDot( data, isMain )
	_redPoint:setVisible( _flag )

	return cellBg
end
-- 构造没有武将
function HeroListLayer:buildBuyCell( saveData )
	-- dump( data, "data" )
	local data = saveData.db
	local cellBg = cc.Sprite:create()
	local path = "res/Main/role/list/gray.png"
	local bg = cc.Sprite:create( path )
	local bgSize = bg:getContentSize()
	cellBg:setContentSize( bgSize )
	-- 武将
    local _heroPath = string.format("res/Main/hero/list/%s.png", data.picture)
    if not zc.checkFileExist( _heroPath ) then
        _heroPath = "res/Main/hero/list/1.png"
    end
	local heroSp = cc.Sprite:create( _heroPath )
	heroSp:setScale(0.4436)
	heroSp:setAnchorPoint( 0, 0.5 )
	heroSp:setPosition( 1, bgSize.height/2 )
	bg:addChild( heroSp )
	zc.setGray( heroSp )

 	if saveData.canBuy then
		-- 称号
		local title = zc.createLabel({
	        text = data.title,
	        fontSize = 18,
	        pos = cc.p( bgSize.width - 120, bgSize.height - 25 ),
	        color = cc.c3b( 76, 18, 18 ),
		})
	    bg:addChild( title )
		local titleLeft = cc.Sprite:create( "res/Main/common/lace.png" )
	    titleLeft:setAnchorPoint( 1, 0.5 )
	    titleLeft:setPosition( title:getPositionX() - title:getContentSize().width/2, title:getPositionY() )
	    bg:addChild( titleLeft )
	    local titleRight = cc.Sprite:create( "res/Main/common/lace.png" )
	    titleRight:setAnchorPoint( 0, 0.5 )
	    titleRight:setPosition( title:getPositionX() + title:getContentSize().width/2, title:getPositionY() )
	    titleRight:setFlippedX( true )
	    bg:addChild( titleRight )

	    -- 名字
	    local nameBgWidth = 214
		local nameBgHeight = 32
		local nameBg = ccui.Scale9Sprite:create( cc.rect( 15, 12, 163, 8 ), "res/Main/common/popBg/di_properties.png" )
		nameBg:setContentSize( nameBgWidth, nameBgHeight )
		nameBg:setPosition( bgSize.width - 127, 77 )
		bg:addChild( nameBg )
	    -- 兵器图标
	    local _weaponType = data.weaponType
	    local _nameText = data.name
	    local weaponIcon = cc.Sprite:create( zc.getHeroTypeImg( _weaponType ) )
	    weaponIcon:setPosition( 0, nameBgHeight/2 )
		nameBg:addChild( weaponIcon )
		-- 武将名字
		local name = zc.createLabel({
	        text = _nameText,
	        fontSize = 20,
	        color = cc.c3b( 255, 236, 203 ),
	        pos = cc.p( nameBgWidth/2 + 5, nameBgHeight/2 ),
	        outLine = true,
	        pixel = 1,
		})
		nameBg:addChild( name )

		local _size = cc.size(210, 28)
		local progressBg = ccui.Scale9Sprite:create(cc.rect(9, 0, 1, 26 ), "res/Main/smithy/practice/progressBg.png")
	    progressBg:setContentSize(_size)
	    progressBg:setPosition(nameBg:getPositionX(), nameBg:getPositionY() - 42)
	    bg:addChild(progressBg)

	    local progress = ccui.Scale9Sprite:create(cc.rect(3, 0, 1, 23 ), "res/Main/smithy/practice/progress.png")
	    progress.width = _size.width - 2
	    progress.height = _size.height - 4
	    progress:setContentSize(cc.size(progress.width, progress.height))
	    progress:setAnchorPoint(0, 0.5)
	    progress:setPosition(1, _size.height*0.5)
	    progressBg:addChild(progress)
	    cellBg.progress = progress

	    local progress2 = ccui.Scale9Sprite:create(cc.rect(3, 0, 1, 23 ), "res/Main/role/list/fullProgress.png")
	    progress2:setContentSize(cc.size(progress.width, progress.height))
	    progress2:setAnchorPoint(0, 0.5)
	    progress2:setPosition(1, _size.height*0.5)
	    progressBg:addChild(progress2)
	    cellBg.progress2 = progress2

	    local numLab = zc.createLabel({
	    	text = "",
	    	fontSize = 20,
	    	color = display.COLOR_YELLOW,
	    	outLine = true,
	    })
	    numLab:setPosition(_size.width*0.5, _size.height*0.5)
	    progressBg:addChild(numLab)
	    cellBg.numLab = numLab

	    local canCompose2 = zc.createSprite("res/Main/role/list/canCompose2.png")
	    canCompose2:setPosition(numLab:getPosition())
	    progressBg:addChild(canCompose2)
	    cellBg.canComposeImg2 = canCompose2
	    -- 框
	    local frame = ccui.Scale9Sprite:create( cc.rect( 13, 60, 9, 62 ), "res/Main/common/frame_s.png" )
	    frame:setContentSize( bgSize.width, bgSize.height + 2 )
	    frame:setPosition( bgSize.width/2, bgSize.height/2 )
	    bg:addChild( frame )
		-- 资质
		local _zizhiPos = cc.p(23,25)
		local qualificationsBg2 = cc.Sprite:create( "res/Main/role/qualifications_bg2.png" )
		-- qualificationsBg2:setScale( 0.45 )
		qualificationsBg2:setPosition( _zizhiPos )
		bg:addChild( qualificationsBg2 )
		local qualificationsBg = cc.Sprite:create( "res/Main/role/qualifications_bg.png" )
		qualificationsBg:setScale( 0.45 )
		qualificationsBg:setPosition( _zizhiPos )
		bg:addChild( qualificationsBg )
	    local talentBg = zc.createSprite("res/Main/talent/talentBg.png")
	    talentBg:setPosition( _zizhiPos )
	    bg:addChild(talentBg)
	    talentBg:setScale(0.2)
		local qualificationsSp = cc.Sprite:create( zc.getHeroQualificationsPath( data.qualifications, 2 ) )
		qualificationsSp:setPosition( _zizhiPos )
		qualificationsSp:setScale( 0.55 )
		bg:addChild( qualificationsSp )

	    local canCompose = zc.createSprite("res/Main/role/list/canCompose.png")
	    canCompose:setAnchorPoint(0, 1)
	    canCompose:setPosition(0,  bgSize.height)
	    bg:addChild(canCompose)
	    cellBg.canComposeImg = canCompose
	else
	    -- 框
	    local frame = ccui.Scale9Sprite:create( cc.rect( 13, 60, 9, 62 ), "res/Main/common/frame_s.png" )
	    frame:setContentSize( bgSize.width, bgSize.height + 2 )
	    frame:setPosition( bgSize.width/2, bgSize.height/2 )
	    bg:addChild( frame )

		local unOpen = zc.createSprite("res/Main/role/list/unOpen.png")
		unOpen:setAnchorPoint(0.5, 0.5)
		unOpen:setPosition(bgSize.width/2, bgSize.height/2)
		bg:addChild(unOpen)
		unOpen:setScaleY(123/118)
	end

	-- btn
	local btn = zc.createPushButton({
		normalNode = bg,
		touchSize = bgSize,
		pos = cc.p( bgSize.width/2, bgSize.height/2 ),
		needSwallow = false,
		touchScale = 0.95,
		needEnableWhenMoving = true,
		endCallback = function()
			if saveData.canCompose == 1 then
				local _confirm = ZCConfirmDialog:createWithParams({
                    title = zc.lang("prompt"),
                    showDi = true,
                    msg = zc.lang("is_or_not_zhaomu_hero"),
                    rightCallback = function()
                        zc.sendHttp({
                        	apiName = "Hero_compose",
                        	params = {heroId = saveData.id},
                        	successCallback = function( backData )
                        		PlayerData:updataData(backData)
                        		self:selfFresh()
                        		zc.createPubShowGetHero({id=saveData.id})
                        	end
                        })
                    end
                })
                self:addChild(_confirm, 10)
			elseif saveData.canBuy then
				zc.createPubLayer( data.id )
			else
				zc.tipInfo(zc.lang("general_is_lock"))
			end
		end
	})
    cellBg:addChild( btn )
    cellBg._bg = bg
	
	return cellBg
end

-- 移除所有的cell
function HeroListLayer:removeCell()
	for k, v in pairs( self._ownCell ) do
		v:release()
	end
	self._ownCell = {}
	for k, v in pairs( self._buyCell ) do
		v:release()
	end
	self._buyCell = {}
end


--新手引导点击武将响应
function HeroListLayer:guideFunc()
    local _currentGID = getGuideManager():getCurrentGID()
    if inArray(_currentGID, GuideGroup.BTN_SELECT_HERO)
      or _currentGID == GuideKey.KEY_11402
      or _currentGID == GuideKey.KEY_12309
      or _currentGID == GuideKey.KEY_14303
      then
	    zc.setGuideFuncNextStep(_currentGID)
    end
end

function HeroListLayer:refreshRedDot( data, isMain )
	-- 装备
	if zc.getEquipRedDotStatus({ data }) then
		return true
	end
	-- 武器
	if isMain then
		-- 主角
		if PlayerData:getGodWeaponRedDotState() then
			return true
		end
	else
		-- 武将
		if zc.getChangeWeaponRedDotStatus({ data }) then
			return true
		elseif PlayerData:checkCanClearWeaponsByHeroId( data.id ) then
			return true
		end
	end
	-- 羁绊
	if zc.getFetterRedDotStatus({ data }) then
		return true
	end
	-- 升星
	if zc.getStarupRedDotStatus({ data }) then
		return true
	end
	-- 宝石
	if zc.getGemSetRedDotStatusByHero({ data }) then
		return true
	end

	return false
end

return HeroListLayer