
--[[
    分享弹窗
]]
local SharePopLayer = class("SharePopLayer", function(params)
    return ZCPopLayer:create({isRemoveLayout = true})
end)

function SharePopLayer:create(params)
	return SharePopLayer.new(params)
end

function SharePopLayer:ctor(params)
    self:initData(params)
    self:initUI()
end

function SharePopLayer:initData(params)
    local isGt = zc.isGt()
    self._isGt = isGt
    self._params = params
    --分享对应的平台 
    --0：微信好友
    --1：微信朋友圈
    --2：facebook
    local shareData = {
        cn = {
        	{
                ["platform"] = 0,
                ["imagePath"] = "res/Main/share/weixin.png",
            },
            {
                ["platform"] = 1,
                ["imagePath"] = "res/Main/share/pengyouquan.png",
            }
        },
        tw = {
        	{
                ["platform"] = 2,   -- 是几都无所谓，大陆港台是分开的
                ["imagePath"] = "res/Main/share/facebook.png",
            },
        }
    }

    local platformData = {}
    if isGt then
        platformData = shareData.tw
    else
        platformData = shareData.cn
    end
    self._platformData = platformData

    self._isPop = params._isPop and params._isPop or false
    self._shareItemInfo = params._info or {}
end

function SharePopLayer:initUI()

    local width = self:getContentSize().width
    local height = self:getContentSize().height

    local bg_sp = zc.getSprite({
        src = "res/Main/common/popBg/popup_Bg_blue.png",
    })
    self.containerBg = bg_sp
    local _bgSize = bg_sp:getContentSize()
    bg_sp:setPosition(width/2,height/2)
    self:addContent(bg_sp)

    local _innerBg = zc.getScaleNode("res/Main/common/popBg/di_1.png", cc.size(_bgSize.width - 50, _bgSize.height - 140))
    _innerBg:setPosition(cc.p(_bgSize.width / 2, _bgSize.height / 2 - 10))
    bg_sp:addChild(_innerBg)

    local close = zc.createBackButton({
        pos = cc.p(_bgSize.width-10, _bgSize.height-10),
        listener = function () 
            self:hide({music=true})
        end,
    })
    bg_sp:addChild(close)
    self._close_btn = close

    local _src = "res/Main/share/share_title.png"
    local _titleTextDi = zc.getSprite({
        src = "res/Main/common/popBg/tipDi.png",
        ap = cc.p(0.5, 1),
        pos = cc.p(_bgSize.width/2, _bgSize.height - 10),
    })
    bg_sp:addChild(_titleTextDi, 1)
    local title = zc.getSprite({
        src = _src,
        ap = cc.p(0.5, 1),
        pos = cc.p(_titleTextDi:getPosition()),
    })
    bg_sp:addChild(title, 1)

    local len = #self._platformData
    local x = _bgSize.width / 2 - 50
    local y = _bgSize.height / 2
    local icon_width = 120
    if len == 1 then  -- 港台
    	x = _bgSize.width / 2
    end

    for i = 1, len do
        local platformBtn = zc.createPushButton({
            normalFile = self._platformData[i].imagePath,
            pos = cc.p(x + icon_width* (i-1), y),
            endCallback = function()
                -- print(self._platformData[i].platform)
                self:share(self._platformData[i].platform)
            end
        })
        local txtIndex = i
        local scaleB = 1
        if self._isGt then
            txtIndex = txtIndex + 2
            scaleB = 1.5
        end
        platformBtn:setScale(scaleB)
        bg_sp:addChild(platformBtn)
        local txt = zc.createLabel({
        	text = zc.lang("share_txt_"..txtIndex),
        	color = cc.c3b(115, 41, 12),
        	fontSize = 20,
        	pos = cc.p(platformBtn:getPositionX(), platformBtn:getPositionY() - 60),
        	})
        bg_sp:addChild(txt)
    end
end

function SharePopLayer:share(platform)
    local args = {
        ["imageURL1"] = self._params.imageURL1,
        ["imageURL2"] = self._params.imageURL2,
        ["imageURL3"] = self._params.imageURL3,
        ["imageURL4"] = self._params.imageURL4,
        ["platform"] = platform,
    }
    local sigs = nil
    local platform = cc.Application:getInstance():getTargetPlatform()
    if cc.PLATFORM_OS_ANDROID == platform then

    elseif (cc.PLATFORM_OS_IPHONE == platform) or (cc.PLATFORM_OS_IPAD == platform) then
        local function shareCallback()
            -- 调用分享奖励的接口
            print("in lua shareCallback!!")
            local rewardId = self._shareItemInfo.id 
            local md5Str = PlayerData.info.userId .. rewardId
            print("playerId :".. PlayerData.info.userId.."==rewardId:"..rewardId)
            local md5 = crypto.md5(md5Str)
            local _params = { id = rewardId, check = md5}
            zc.sendHttp({
                apiName = "shareReceive",
                params = _params,
                -- 成功回调
                successCallback = function(backData)
                    table.insert(PlayerData.shareReceived, tostring(rewardId))
                    if self._isPop == true then
                        LayerManager.removeLayout(true)
                    end
                    LayerManager.removeLayout(true)
                    PlayerData:updataData(backData)
                end
                })
        end
        local function shareFailCallback( )
            --[[
                code = 
                -2 未安装微信客户端

                2   facebook未安装
                -2  facebook用户取消操作
            ]]
            -- print("分享失败code="..code)
            -- if tonumber(code) == -2 or tonumber(code) == 2 then
            --     zc.tipInfo(zc.lang("tip_share_failed"))
            -- else
            --     zc.tipInfo(zc.lang("tip_share_failed"))
            -- end
            -- 直接提示分享失败
            zc.tipInfo(zc.lang("tip_share_failed"))
        end
        args.callback = shareCallback
        args.failCallback = shareFailCallback
    end
    zc.luaBridgeCall(LUA_BRIDGE_CLASS,"share",args,sigs)

 --    performWithDelay(self,function()
        
	-- end,0.3)
end


return SharePopLayer